Module span

Module span 

Structs

ByteLocation
A wrapper around a Location that implements From<usize>.
Location
Either references a location in the original source file, or is Location::MISSING.
LocationIndex
LocationResolveError
MissingLocationError
An error that occurs when a Location or Span is missing.
OrderedSpan
A wrapper around Span that properly implements Eq and Ord installed of always being Ordering::Equal.
ResolvedLocation
A Location resolved into line/column information.
ResolvedSpan
Span
References a range of bytes in the original source file.