ByteLocation

Struct ByteLocation 

pub struct ByteLocation(pub Location);
A wrapper around a Location that implements From<usize>.

The Location type itself doesn’t implement From<usize>, because it wants to be absolutely clear that byte offsets are being used instead of than codepoint offsets.

Needed to implement chumsky::span::Span in a manner compatible with chumsky::input::MappedSpan.

Tuple Fields

0: Location

Methods from Deref<Target = Location>