pub struct Location { /* private fields */ }Expand description
Either references a location in the original source file,
or is Location::MISSING.
A location has a total order based on the byte offset,
with Location::MISSING coming after every valid location.
Implementations
Sourceimpl Location
impl Location
Sourcepub const MISSING: Location
pub const MISSING: Location
Indicates that the location information is missing, and doesn’t correspond to a known location in the source file.
For the purposes of a comparison using Ord,
a missing value comes after all present values.
Sourcepub const fn is_missing(self) -> bool
pub const fn is_missing(self) -> bool
Determine if the location is Self::MISSING.
Sourcepub const fn byte_offset(self) -> Result<u64, MissingLocationError>
pub const fn byte_offset(self) -> Result<u64, MissingLocationError>
Return the byte offset of this location,
or a MissingLocationError if missing.
Sourcepub fn to_span(self) -> Span
pub fn to_span(self) -> Span
A span which points only to this location.
Returns Span::MISSING if this location is missing.