pub struct OrderedSpan(pub Span);Expand description
A wrapper around Span that properly implements Eq and Ord
installed of always being Ordering::Equal.
A Span::MISSING is considered greater than all other spans.
Tuple Fields
0: SpanImplementations
Sourceimpl OrderedSpan
impl OrderedSpan
Sourcepub const MISSING: Self
pub const MISSING: Self
The OrderedSpan corresponding to Span::MISSING.
Methods from Deref<Target = Span>
pub const MISSING: Span
Sourcepub fn is_missing(&self) -> bool
pub fn is_missing(&self) -> bool
Check if the span is Self::MISSING.
Sourcepub fn byte_range(&self) -> Result<Range<u64>, MissingLocationError>
pub fn byte_range(&self) -> Result<Range<u64>, MissingLocationError>
Return the range of bytes in the original file,
or a MissingLocationError if missing.
Sourcepub fn byte_len(&self) -> Result<u64, MissingLocationError>
pub fn byte_len(&self) -> Result<u64, MissingLocationError>
Returns the length of the span in bytes,
or a MissingLocationError if missing.
Sourcepub fn start(&self) -> Location
pub fn start(&self) -> Location
The starting location of the span (inclusive),
or Location::MISSING if missing.
Sourcepub fn end(&self) -> Location
pub fn end(&self) -> Location
The ending location of the span (exclusive),
or Location::MISSING if missing.